body{
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:18px;
  line-height:1.5;
  --wp--style--block-gap:2em;
}

p{
  line-height:1.8;
}

.editor-post-title__block{
  font-size:2.5em;
  font-weight:800;
  margin-bottom:1em;
  margin-top:2em;
}